@@ -55,7 +55,7 @@ def download(args):
 
     # The data is returned as JSON, use AIRR library to write out data
     data = resp.json()
-    airr.write_repertoire("testdata.airr.json",
+    airr.write_repertoire("AIRR_repertoire_file.json",
                           data["Repertoire"], info=data["Info"])
 
     # Print out some Info
@@ -65,12 +65,12 @@ def download(args):
 
     # Save them out to a file
     print("Received " + str(len(data["Repertoire"]))
-          + " repertoires. Saved as testdata.airr.json")
-    with open("legend_for_testdata.json", "w") as fileout:
+          + " repertoires. Saved as AIRR_repertoire_file.json")
+    with open("legend.json", "w") as fileout:
         print("{", file=fileout)
         print('    "2839362682105696746-242ac113-0001-012":"Twin 2A",',
               file=fileout)
         print('    "2939134772391776746-242ac113-0001-012":"Twin 2B"',
               file=fileout)
         print("}", file=fileout)
-    print("json file for legend saved as legend_for_testdata.json")
+    print("json file for legend saved as legend.json")
